#
# spec file for package tolua
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libtolua5
Name:           tolua
Version:        5.2.4
Release:        4.4
Summary:        Greatly simplifies the integration of C/C++ code with Lua
License:        GPL-2.0+
Group:          Development/Libraries/Other
Url:            http://www.tecgraf.puc-rio.br/~celes/tolua/
Source:         http://www.tecgraf.puc-rio.br/~celes/tolua/tolua-%{version}.tar.gz
Patch0:         %{name}-5.2.0-optflags.patch
Patch1:         %{name}-5.2.0-shared.patch
BuildRequires:  gcc-c++
BuildRequires:  lua-devel
Requires:       %{libname} = %{version}

%description
tolua is a tool that greatly simplifies the integration of
C/C++ code with Lua.

Based on a 'cleaned' header file, tolua automatically generates
the binding code to access C/C++ features from Lua.

Using Lua-5.0 API and tag method facilities, the current version
automatically maps C/C++ constants, external variables, functions,
namespace, classes, and methods to Lua. It also provides
facilities to create Lua modules.

%package -n %{libname}
Summary:        Shared libraries for tolua
Group:          System/Libraries

%description -n %{libname}
This package provides shared libraries for tolua.

%package -n libtolua-devel
Summary:        Development headers for tolua
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Provides:       tolua-devel = %{version}
Obsoletes:      tolua-devel < %{version}

%description -n libtolua-devel
This package contains all necessary include files and libraries
needed to develop applications that require these.

%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build
# no jobserver
make -e \
LUA=%{_prefix} \
LUALIB=%{_libdir} \
LUAINC=%{_includedir}/lua%{lua_version} \
WARN='%{optflags}'

%install
%make_install LIBDIR=%{_libdir}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%doc README
%{_bindir}/%{name}

%files -n %{libname}
%{_libdir}/lib%{name}.so.5
%{_libdir}/lib%{name}.so.5.2
%{_libdir}/lib%{name}.so.%{version}

%files -n libtolua-devel
%{_includedir}/%{name}.h
%{_libdir}/lib%{name}.so

%changelog
* Tue Aug 23 2022 Callum Farmer <gmbr3@opensuse.org>
- Make tolua-5.2.0-shared.patch more useful
  * Remove LUA_C89_NUMBERS
- Prevent ansi by overriding WARN
- Add optflags by overriding WARN
* Thu Aug 12 2021 Callum Farmer <gmbr3@opensuse.org>
- Use GNU11 instead of C99
* Fri Apr  9 2021 Callum Farmer <gmbr3@opensuse.org>
- Fix build with Lua 5.4.3
* Thu Jul 13 2017 tchvatal@suse.com
- Fix building with namespaced lua, adapt patches:
  * tolua-5.2.0-optflags.patch
  * tolua-5.2.0-shared.patch
* Sun Nov 22 2015 rpm@fthiessen.de
- Update to 5.2.4
  * Modified tolua-5.2.0-shared.patch (version number of shared lib)
* Wed Jul 22 2015 i@marguerite.su
- add patch: tolua-5.2.0-optflags.patch
  * build with optflags
- add patch: tolua-5.2.0-shared.patch
  * build shared library
* Sun Jul 29 2012 pascal.bleser@opensuse.org
- update to 5.2.0
* Wed Sep 28 2011 pascal.bleser@opensuse.org
- copy to devel:languages:lua
* Sat Feb 26 2011 pascal.bleser@opensuse.org
- update to 5.1.4
* Sun Nov  4 2007 toni@links2linux.de
- update to 5.1b
- splitted of sub-package libtolua-devel
* Sat Dec 30 2006 toni@links2linux.de
- build SuSE-10.2, corrected BuildRequires
* Sun Sep 17 2006 toni@links2linux.de
- build for packman
* Sat Jan 28 2006 oc2pus@arcor.de 5.0-0.oc2pus.1
- initial release tolua-5.0
- repacked as tar.bz2
